@@ -17,6 +17,57 @@ logger = logging.getLogger("main")
 
 SDB_NAMESPACE = "{http://sdb.amazonaws.com/doc/2009-04-15/}"
 
+def base10toN(num,n):
+    """Change a  to a base-n number.
+    Up to base-36 is supported without special notation."""
+    num_rep={10:'a',
+         11:'b',
+         12:'c',
+         13:'d',
+         14:'e',
+         15:'f',
+         16:'g',
+         17:'h',
+         18:'i',
+         19:'j',
+         20:'k',
+         21:'l',
+         22:'m',
+         23:'n',
+         24:'o',
+         25:'p',
+         26:'q',
+         27:'r',
+         28:'s',
+         29:'t',
+         30:'u',
+         31:'v',
+         32:'w',
+         33:'x',
+         34:'y',
+         35:'z'}
+    new_num_string=''
+    current=num
+    while current!=0:
+        remainder=current%n
+        if 36>remainder>9:
+            remainder_string=num_rep[remainder]
+        elif remainder>=36:
+            remainder_string='('+str(remainder)+')'
+        else:
+            remainder_string=str(remainder)
+        new_num_string=remainder_string+new_num_string
+        current=current/n
+    return new_num_string
+
+
+def base10to36(i):
+    return base10toN(i, 36)
+        
+
+def base36to10(s):
+    return int(s, 36)
+
 
 def sdb_now(offset=0):
     """Return an 11 character, zero padded string with the current Unixtime.
@@ -517,7 +568,6 @@ class AmazonSDB:
         else:
             next_token = None
         items = xml.findall(".//%sItem" % SDB_NAMESPACE)
-        results = {}
         for item in items:
             key = item.find("./%sName" % SDB_NAMESPACE).text
             attributes = item.findall("%sAttribute" % SDB_NAMESPACE)
